==> awscala_2.11-0.4.2-sources.jar: awscala/ec2/InstanceType.scala <==
package awscala.ec2

import com.amazonaws.services.{ ec2 => aws }

object InstanceType {

  val C1_Medium = aws.model.InstanceType.C1Medium
  val C1_Xlarge = aws.model.InstanceType.C1Xlarge
  val Cc1_4xlarge = aws.model.InstanceType.Cc14xlarge
  val Cc2_8xlarge = aws.model.InstanceType.Cc28xlarge
  val Cg1_4xlarge = aws.model.InstanceType.Cg14xlarge
  val Cr1_8xlarge = aws.model.InstanceType.Cr18xlarge
  val Hi1_4xlarge = aws.model.InstanceType.Hi14xlarge
  val Hs1_8xlarge = aws.model.InstanceType.Hs18xlarge
  val M1_Large = aws.model.InstanceType.M1Large
  val M1_Medium = aws.model.InstanceType.M1Medium
  val M1_Small = aws.model.InstanceType.M1Small
  val M1_Xlarge = aws.model.InstanceType.M1Xlarge
  val M2_2xlarge = aws.model.InstanceType.M22xlarge
  val M2_4xlarge = aws.model.InstanceType.M24xlarge
  val M2_Xlarge = aws.model.InstanceType.M2Xlarge
  val M3_2xlarge = aws.model.InstanceType.M32xlarge
  val M3_Xlarge = aws.model.InstanceType.M3Xlarge
  val T1_Micro = aws.model.InstanceType.T1Micro
  val C3_2xlarge = aws.model.InstanceType.C32xlarge
  val C3_4xlarge = aws.model.InstanceType.C34xlarge
  val C3_8xlarge = aws.model.InstanceType.C38xlarge
  val C3_Large = aws.model.InstanceType.C3Large
  val C3_Xlarge = aws.model.InstanceType.C3Xlarge
  val G2_2xlarge = aws.model.InstanceType.G22xlarge
  val I2_2xlarge = aws.model.InstanceType.I22xlarge
  val I2_4xlarge = aws.model.InstanceType.I24xlarge
  val I2_8xlarge = aws.model.InstanceType.I28xlarge
  val I2_Xlarge = aws.model.InstanceType.I2Xlarge
  val R3_2xlarge = aws.model.InstanceType.R32xlarge
  val R3_4xlarge = aws.model.InstanceType.R34xlarge
  val R3_8xlarge = aws.model.InstanceType.R38xlarge
  val R3_Large = aws.model.InstanceType.R3Large
  val R3_Xlarge = aws.model.InstanceType.R3Xlarge
}

==> awscala_2.11-0.5.1-sources.jar: awscala/ec2/InstanceType.scala <==
package awscala.ec2

import com.amazonaws.services.{ ec2 => aws }

object InstanceType {
  val T2_Small = aws.model.InstanceType.T2Small
  val T2_Micro = aws.model.InstanceType.T2Micro
  val T2_Medium = aws.model.InstanceType.T2Medium
  val C1_Medium = aws.model.InstanceType.C1Medium
  val C1_Xlarge = aws.model.InstanceType.C1Xlarge
  val Cc1_4xlarge = aws.model.InstanceType.Cc14xlarge
  val Cc2_8xlarge = aws.model.InstanceType.Cc28xlarge
  val Cg1_4xlarge = aws.model.InstanceType.Cg14xlarge
  val Cr1_8xlarge = aws.model.InstanceType.Cr18xlarge
  val Hi1_4xlarge = aws.model.InstanceType.Hi14xlarge
  val Hs1_8xlarge = aws.model.InstanceType.Hs18xlarge
  val M1_Large = aws.model.InstanceType.M1Large
  val M1_Medium = aws.model.InstanceType.M1Medium
  val M1_Small = aws.model.InstanceType.M1Small
  val M1_Xlarge = aws.model.InstanceType.M1Xlarge
  val M2_2xlarge = aws.model.InstanceType.M22xlarge
  val M2_4xlarge = aws.model.InstanceType.M24xlarge
  val M2_Xlarge = aws.model.InstanceType.M2Xlarge
  val M3_2xlarge = aws.model.InstanceType.M32xlarge
  val M3_Xlarge = aws.model.InstanceType.M3Xlarge
  val M3_Medium = aws.model.InstanceType.M3Medium
  val M3_Large = aws.model.InstanceType.M3Large
  val T1_Micro = aws.model.InstanceType.T1Micro
  val C3_2xlarge = aws.model.InstanceType.C32xlarge
  val C3_4xlarge = aws.model.InstanceType.C34xlarge
  val C3_8xlarge = aws.model.InstanceType.C38xlarge
  val C3_Large = aws.model.InstanceType.C3Large
  val C3_Xlarge = aws.model.InstanceType.C3Xlarge
  val C4_Large = aws.model.InstanceType.C4Large
  val C4_Xlarge = aws.model.InstanceType.C4Xlarge
  val C4_2xlarge = aws.model.InstanceType.C42xlarge
  val C4_4xlarge = aws.model.InstanceType.C44xlarge
  val C4_8xlarge = aws.model.InstanceType.C48xlarge
  val G2_2xlarge = aws.model.InstanceType.G22xlarge
  val I2_2xlarge = aws.model.InstanceType.I22xlarge
  val I2_4xlarge = aws.model.InstanceType.I24xlarge
  val I2_8xlarge = aws.model.InstanceType.I28xlarge
  val I2_Xlarge = aws.model.InstanceType.I2Xlarge
  val R3_2xlarge = aws.model.InstanceType.R32xlarge
  val R3_4xlarge = aws.model.InstanceType.R34xlarge
  val R3_8xlarge = aws.model.InstanceType.R38xlarge
  val R3_Large = aws.model.InstanceType.R3Large
  val R3_Xlarge = aws.model.InstanceType.R3Xlarge
}
